==> ssp-center-api-0.5.12-yt-20190603.014204-17-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActivityRatioDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

public class ActivityRatioDto implements Serializable {

	private static final long serialVersionUID = 5126263884975870956L;
	private Long actGroupId;
	private Long activityId;
	private Integer actSource;
	private Long slotId;
	private Integer ratio;
	private Integer isDefault;
	private Integer belongTo;
	
	private String tag;
	private String actName;
	private Integer activityType;
	private String subType;
	private Integer isEnable;
	private Integer isPublish;
	private Integer overseas;
	private Integer num;
    /**
     * 周期活动类型
     */
    private Integer           cronType;

    /**
     * 周期表达式
     */
    private String            cronExpression;

	/**
	 * 广告位地域类型ID
	 */
	private Long regionId;

	//归属媒体运营
	public static final int MEDIA_BELONGTO = 0;
	//归属活动运营
	public static final int ACT_BELONGTO = 1;
	//默认活动
	public static final int DEFAULT_ACT = 1;

	/**
	 * 活动链接名称
	 */
	private String  activityName;

	/**
	 * 活动链接url
	 */
	private String  activityUrl;
	
	public Long getActGroupId() {
		return actGroupId;
	}
	public void setActGroupId(Long actGroupId) {
		this.actGroupId = actGroupId;
	}
	public Long getActivityId() {
		return activityId;
	}
	public void setActivityId(Long activityId) {
		this.activityId = activityId;
	}
	public Integer getActSource() {
		return actSource;
	}
	public void setActSource(Integer actSource) {
		this.actSource = actSource;
	}
	public Long getSlotId() {
		return slotId;
	}
	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}
	public Integer getRatio() {
		return ratio;
	}
	public void setRatio(Integer ratio) {
		this.ratio = ratio;
	}
	public Integer getIsDefault() {
		return isDefault;
	}
	public void setIsDefault(Integer isDefault) {
		this.isDefault = isDefault;
	}
	public Integer getBelongTo() {
		return belongTo;
	}
	public void setBelongTo(Integer belongTo) {
		this.belongTo = belongTo;
	}
	public Integer getActivityType() {
		return activityType;
	}
	public void setActivityType(Integer activityType) {
		this.activityType = activityType;
	}
	public String getSubType() {
		return subType;
	}
	public void setSubType(String subType) {
		this.subType = subType;
	}
	public Integer getIsEnable() {
		return isEnable;
	}
	public void setIsEnable(Integer isEnable) {
		this.isEnable = isEnable;
	}
	public Integer getIsPublish() {
		return isPublish;
	}
	public void setIsPublish(Integer isPublish) {
		this.isPublish = isPublish;
	}
	public String getActName() {
		return actName;
	}
	public void setActName(String actName) {
		this.actName = actName;
	}
	public String getTag() {
		return tag;
	}
	public void setTag(String tag) {
		this.tag = tag;
	}

	public Integer getOverseas() {
		return overseas;
	}

	public void setOverseas(Integer overseas) {
		this.overseas = overseas;
	}
	
    public Integer getCronType() {
        return cronType;
    }

    public void setCronType(Integer cronType) {
        this.cronType = cronType;
    }
    
    public String getCronExpression() {
        return cronExpression;
    }
    
    public void setCronExpression(String cronExpression) {
        this.cronExpression = cronExpression;
    }

	public Integer getNum() {
		return num;
	}

	public void setNum(Integer num) {
		this.num = num;
	}

	public Long getRegionId() {
		return regionId;
	}

	public void setRegionId(Long regionId) {
		this.regionId = regionId;
	}

	public String getActivityName() {
		return activityName;
	}

	public void setActivityName(String activityName) {
		this.activityName = activityName;
	}

	public String getActivityUrl() {
		return activityUrl;
	}

	public void setActivityUrl(String activityUrl) {
		this.activityUrl = activityUrl;
	}
}

==> ssp-center-api-0.5.61-yt2-20190905.092146-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActivityRatioDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

public class ActivityRatioDto implements Serializable {

	private static final long serialVersionUID = 5126263884975870956L;
	private Long actRatioId;
	private Long actGroupId;
	private Long activityId;
	private Integer actSource;
	private Long slotId;
	private Integer ratio;
	private Integer isDefault;
	private Integer belongTo;
	/**
	 * 所属组
	 */
	private Byte belongToGroup;


	private String tag;
	private String actName;
	private Integer activityType;
	private String subType;
	private Integer isEnable;
	private Integer isPublish;
	private Integer overseas;
	private Integer num;
	private String dayuModel;//用于构造和 大禹返回一样的结构值
    /**
     * 周期活动类型
     */
    private Integer           cronType;

    /**
     * 周期表达式
     */
    private String            cronExpression;

	/**
	 * 广告位地域类型ID
	 */
	private Long regionId;


	//归属媒体运营
	public static final int MEDIA_BELONGTO = 0;
	//归属活动运营
	public static final int ACT_BELONGTO = 1;
	//默认活动
	public static final int DEFAULT_ACT = 1;

	public Long getActRatioId() {
		return actRatioId;
	}

	public void setActRatioId(Long actRatioId) {
		this.actRatioId = actRatioId;
	}

	/**
	 * 活动链接名称
	 */
	private String  activityName;

	/**
	 * 活动链接url
	 */
	private String  activityUrl;

	/**
	 * 依次投放活动组-比例 测试开关
	 */
	private Byte actOrderGroupRatioStatus;
	
	public Long getActGroupId() {
		return actGroupId;
	}
	public void setActGroupId(Long actGroupId) {
		this.actGroupId = actGroupId;
	}
	public Long getActivityId() {
		return activityId;
	}
	public void setActivityId(Long activityId) {
		this.activityId = activityId;
	}
	public Integer getActSource() {
		return actSource;
	}
	public void setActSource(Integer actSource) {
		this.actSource = actSource;
	}
	public Long getSlotId() {
		return slotId;
	}
	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}
	public Integer getRatio() {
		return ratio;
	}
	public void setRatio(Integer ratio) {
		this.ratio = ratio;
	}
	public Integer getIsDefault() {
		return isDefault;
	}
	public void setIsDefault(Integer isDefault) {
		this.isDefault = isDefault;
	}
	public Integer getBelongTo() {
		return belongTo;
	}
	public void setBelongTo(Integer belongTo) {
		this.belongTo = belongTo;
	}
	public Integer getActivityType() {
		return activityType;
	}
	public void setActivityType(Integer activityType) {
		this.activityType = activityType;
	}
	public String getSubType() {
		return subType;
	}
	public void setSubType(String subType) {
		this.subType = subType;
	}
	public Integer getIsEnable() {
		return isEnable;
	}
	public void setIsEnable(Integer isEnable) {
		this.isEnable = isEnable;
	}
	public Integer getIsPublish() {
		return isPublish;
	}
	public void setIsPublish(Integer isPublish) {
		this.isPublish = isPublish;
	}
	public String getActName() {
		return actName;
	}
	public void setActName(String actName) {
		this.actName = actName;
	}
	public String getTag() {
		return tag;
	}
	public void setTag(String tag) {
		this.tag = tag;
	}

	public Integer getOverseas() {
		return overseas;
	}

	public void setOverseas(Integer overseas) {
		this.overseas = overseas;
	}
	
    public Integer getCronType() {
        return cronType;
    }

    public void setCronType(Integer cronType) {
        this.cronType = cronType;
    }
    
    public String getCronExpression() {
        return cronExpression;
    }
    
    public void setCronExpression(String cronExpression) {
        this.cronExpression = cronExpression;
    }

	public Integer getNum() {
		return num;
	}

	public void setNum(Integer num) {
		this.num = num;
	}

	public Long getRegionId() {
		return regionId;
	}

	public void setRegionId(Long regionId) {
		this.regionId = regionId;
	}

	public String getActivityName() {
		return activityName;
	}

	public void setActivityName(String activityName) {
		this.activityName = activityName;
	}

	public String getActivityUrl() {
		return activityUrl;
	}

	public void setActivityUrl(String activityUrl) {
		this.activityUrl = activityUrl;
	}

	public String getDayuModel() {
		return dayuModel;
	}

	public void setDayuModel(String dayuModel) {
		this.dayuModel = dayuModel;
	}

	public Byte getActOrderGroupRatioStatus() {
		return actOrderGroupRatioStatus;
	}

	public void setActOrderGroupRatioStatus(final Byte actOrderGroupRatioStatus) {
		this.actOrderGroupRatioStatus = actOrderGroupRatioStatus;
	}

	public Byte getBelongToGroup() {
		return belongToGroup;
	}

	public void setBelongToGroup(final Byte belongToGroup) {
		this.belongToGroup = belongToGroup;
	}
}
